Package to Manage bibliographies.
=================================

Description:
------------

The package contains two subpackages.

-  yapbib: Methods to manage a bibliography
-  query_ads: Methods to Query ADS (Harvard Database)

Features:
---------

-  It provides methods to import from bibtex and ADS (Harvard database)
   portable format.
-  Supports exporting to bibtex, latex, html and xml and two ad-hoc
   formats (short and full descriptions).
-  Include scripts to manipulate databases, get bibliography from ADS
   online database and extract citations from a LaTeX document.
-  Easy to use in your own scripts

Documentation
-------------

http://fiolj.gitlab.io/biblio-py/

Scripts:
--------

There are three available ready-to-use scripts that serve as examples of
use:

============= ==================================================
Script        Function
============= ==================================================
bibmanage.py: Manage bibliography
bibextract.py Extract citations from tex source
get_papers.py Retrieve bibliography information from Harvard ADS
============= ==================================================
